@@ -19,20 +19,29 @@ def redirect(request, link='/', chain=False):
     return HttpResponseRedirect(link)
 
 
-def render(request, template_name, context, debug=False):
+def render(request, template_name, context, debug=False, mimetype=None):
     if hasattr(settings, 'AUTH_PROFILE_MODULE'):
         if 'user_profile' in context:
-            raise KeyError, "langacore.kit.django.helpers.render() doesn't accept contexts with 'user_profile'"
+            raise KeyError, ("langacore.kit.django.helpers.render() doesn't "
+                             "accept contexts with 'user_profile'")
         if 'other_user_profile' in context:
-            raise KeyError, "langacore.kit.django.helpers.render() doesn't accept contexts with 'other_user_profile'"
-    
-        context['user_profile'] = request.user.get_profile() if request.user.is_authenticated() else None 
-        context['other_user_profile'] = context['other_user'].get_profile() if 'other_user' in context else None
+            raise KeyError, ("langacore.kit.django.helpers.render() doesn't "
+                             "accept contexts with 'other_user_profile'")
+
+        context['user_profile'] = request.user.get_profile() \
+                                  if request.user.is_authenticated() else None
+        context['other_user_profile'] = context['other_user'].get_profile() \
+                                        if 'other_user' in context else None
 
     if debug:
         for key in context:
-            print "context['%s'] = %s (type: %s) (repr: %s)" % (key, str(context[key]), type(context[key]), repr(context[key]))
-    return django.shortcuts.render_to_response(template_name, RequestContext(request, context))
+            print "context['%s'] = %s (type: %s) (repr: %s)" % (key,
+                                                                str(context[key]),
+                                                                type(context[key]),
+                                                                repr(context[key]))
+    return django.shortcuts.render_to_response(template_name,
+                                               RequestContext(request, context),
+                                               mimetype=mimetype)
 
 
 class Choice(object):
